instrumenttools.EFlatClarinet
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet

.. autoclass:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.EFlatClarinet.EFlatClarinet.EFlatClarinet.__repr__
   :noindex:
